#[entry]Expand description
Declares the program entry point called after runtime initialization.
The function must have the signature [unsafe] fn() -> !.
#[entry]Declares the program entry point called after runtime initialization.
The function must have the signature [unsafe] fn() -> !.