Machine interrupt control for MIK32.
The runtime disables and restores the global machine interrupt enable bit
(mstatus.MIE) together with machine external interrupts (mie.MEIE).
This matches the interrupt model used by MIK32 applications.
Structs
- Restore
State - Previous interrupt state returned by
disable.
Functions
- disable
- Disables global machine interrupts and machine external interrupts.
- enable⚠
- Enables global machine interrupts and machine external interrupts.
- free
- Runs
fwith global machine interrupts and machine external interrupts disabled, then restores the previous state. - restore⚠
- Restores the interrupt state returned by
disable.