pub fn disable() -> RestoreStateExpand description
Disables global machine interrupts and machine external interrupts.
Returns the previous state, which can later be passed to restore.
pub fn disable() -> RestoreStateDisables global machine interrupts and machine external interrupts.
Returns the previous state, which can later be passed to restore.